<?php
header("Content-Type: application/vnd.ms-excel");
header("content-disposition: attachment;filename=listadopaciente.xls");

require_once("../class/class.conectar.php");
require_once("../class/class.usudep.php");

$Objcon = new Conectar();
$conex = $Objcon->con();

$idesp=$_GET['esp'];
$idtp=$_GET['tp'];
$idj=$_GET['idj'];
$ids=$_GET['ids'];
$tcont=$_GET['tcont'];
$tbusq=$_GET['tbusq'];
$nombre=$_GET['nombre'];

$Objud = new UsuarioDependencia();
$res_ud = array();

if($tbusq==1){
if($idesp!=0 and $idtp!=0 ){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_esp_tp($conex,$idj,$ids,$idtp,$idesp);
	}else{
	$res_ud = $Objud->listar_per_dep_esp_tp_c($conex,$idj,$ids,$idtp,$idesp,$tcont);
	}
}elseif($idesp!=0 and $idtp!=0 ){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_esp_tp($conex,$idj,$ids,$idtp,$idesp);
	}else{
	$res_ud = $Objud->listar_per_dep_esp_tp_c($conex,$idj,$ids,$idtp,$idesp,$tcont);
	}
}elseif($idesp==0 and $idtp!=0){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_tp($conex,$idj,$ids,$idtp);
	}else{
	$res_ud = $Objud->listar_per_dep_tp_c($conex,$idj,$ids,$idtp,$tcont);
	}
}elseif($idesp!=0 and $idtp==0){
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep_esp($conex,$idj,$ids,$idesp);
	}else{
	$res_ud = $Objud->listar_per_dep_esp_c($conex,$idj,$ids,$idesp,$tcont);
	}
}else{
	if($tcont==0){
	$res_ud = $Objud->listar_per_dep($conex,$idj,$ids);
	}else{
	$res_ud = $Objud->listar_per_dep_c($conex,$idj,$ids,$tcont);
	}
}
}else{
	$res_ud = $Objud->listar_per_nombre($conex,$idj,$ids,$nombre);
}

$sumap=0;



$cadenalis="";
$cadenalis="<table align='center' class='FacetFormTABLE'><tr><td colspan='6'class='FacetFieldCaptionTDT' align='center'> PERSONAL ASISTENCIAL </td></tr>";
$cadenalis=$cadenalis."<tr><td class='FacetFieldCaptionTD' align='center' width='250'>APELLIDOS Y NOMBRES</td><td class='FacetFieldCaptionTD' align='center' width='130'>TIPO PERSONAL</td><td class='FacetFieldCaptionTD' align='center' width='130'>ESPECIALIDAD</td><td class='FacetFieldCaptionTD' align='center' width='130'>TIPO DE CONTRATO</td><td class='FacetFieldCaptionTD' align='center' width='100'>FECHA DE INGRESO</td><td class='FacetFieldCaptionTD' align='center' width='70'>PERIOD. LAB.</td></tr>";
	
for ($i=0;$i<count($res_ud);$i++){
$codigo = $res_ud[$i]['cod'];
$muestra = $muestra."<input type='hidden' id='codper".$a."'  name='codper".$a."' value='".$codigo."'>";
$cadenalis=$cadenalis."<tr><td align='left'>".utf8_encode($res_ud[$i]['nombre'])."</td><td align='center'>".$res_ud[$i]['tpersona']."</td><td align='center'>".$res_ud[$i]['especialidad']."</td><td align='center'>".$res_ud[$i]['tipocontrato']."</td><td align='center'>".$res_ud[$i]['fingreso']."</td><td align='center'>".$res_ud[$i]['tiempo']."</td></tr>";
$sumap = $sumap +1;
}
$cadenalis=$cadenalis."<tr><td colspan='6' align='center'>El numero de Personal es ".$sumap."</td></tr>";
$cadenalis=$cadenalis."</table>";
?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
</head>
<body>
<?php
echo $cadenalis;
?>
</body>
</html>